==> tencentcloud-sdk-java-sms-3.1.455-sources.jar: com/tencentcloudapi/sms/v20210111/models/PullSmsSendStatusByPhoneNumberResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.sms.v20210111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class PullSmsSendStatusByPhoneNumberResponse extends AbstractModel{

    /**
    * 下发状态响应集合。
    */
    @SerializedName("PullSmsSendStatusSet")
    @Expose
    private PullSmsSendStatus [] PullSmsSendStatusSet;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 下发状态响应集合。 
     * @return PullSmsSendStatusSet 下发状态响应集合。
     */
    public PullSmsSendStatus [] getPullSmsSendStatusSet() {
        return this.PullSmsSendStatusSet;
    }

    /**
     * Set 下发状态响应集合。
     * @param PullSmsSendStatusSet 下发状态响应集合。
     */
    public void setPullSmsSendStatusSet(PullSmsSendStatus [] PullSmsSendStatusSet) {
        this.PullSmsSendStatusSet = PullSmsSendStatusSet;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public PullSmsSendStatusByPhoneNumberResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public PullSmsSendStatusByPhoneNumberResponse(PullSmsSendStatusByPhoneNumberResponse source) {
        if (source.PullSmsSendStatusSet != null) {
            this.PullSmsSendStatusSet = new PullSmsSendStatus[source.PullSmsSendStatusSet.length];
            for (int i = 0; i < source.PullSmsSendStatusSet.length; i++) {
                this.PullSmsSendStatusSet[i] = new PullSmsSendStatus(source.PullSmsSendStatusSet[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "PullSmsSendStatusSet.", this.PullSmsSendStatusSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-sms-3.1.1281-sources.jar: com/tencentcloudapi/sms/v20210111/models/PullSmsSendStatusByPhoneNumberResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.sms.v20210111.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class PullSmsSendStatusByPhoneNumberResponse extends AbstractModel {

    /**
    * 下发状态响应集合。
    */
    @SerializedName("PullSmsSendStatusSet")
    @Expose
    private PullSmsSendStatus [] PullSmsSendStatusSet;

    /**
    * 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 下发状态响应集合。 
     * @return PullSmsSendStatusSet 下发状态响应集合。
     */
    public PullSmsSendStatus [] getPullSmsSendStatusSet() {
        return this.PullSmsSendStatusSet;
    }

    /**
     * Set 下发状态响应集合。
     * @param PullSmsSendStatusSet 下发状态响应集合。
     */
    public void setPullSmsSendStatusSet(PullSmsSendStatus [] PullSmsSendStatusSet) {
        this.PullSmsSendStatusSet = PullSmsSendStatusSet;
    }

    /**
     * Get 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public PullSmsSendStatusByPhoneNumberResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public PullSmsSendStatusByPhoneNumberResponse(PullSmsSendStatusByPhoneNumberResponse source) {
        if (source.PullSmsSendStatusSet != null) {
            this.PullSmsSendStatusSet = new PullSmsSendStatus[source.PullSmsSendStatusSet.length];
            for (int i = 0; i < source.PullSmsSendStatusSet.length; i++) {
                this.PullSmsSendStatusSet[i] = new PullSmsSendStatus(source.PullSmsSendStatusSet[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "PullSmsSendStatusSet.", this.PullSmsSendStatusSet);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
